netapp_ontap.models.volume_constituents_space API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_constituents_space`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeConstituentsSpaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeConstituentsSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `afs_total: Size GET POST PATCH`

    Total size of AFS, excluding snap-reserve, in bytes.

  `available: Size GET`

    The available space, in bytes.

  `available_percent: Size GET POST PATCH`

    The space available, as a percent.

  `block_storage_inactive_user_data: Size GET`

    The size that is physically used in the block storage of the volume and has a cold temperature. In bytes. This parameter is only supported if the volume is in an aggregate that is either attached to a cloud store or could be attached to a cloud store.

  `capacity_tier_footprint: Size GET`

    Space used by capacity tier for this volume in the FabricPool aggregate, in bytes.

  `footprint: Size GET`

    Data used for this volume in the aggregate, in bytes.

  `large_size_enabled: bool GET POST PATCH`

    Specifies whether the support for large volumes and large files is enabled on the volume.

  `local_tier_footprint: Size GET`

    Space used by the local tier for this volume in the aggregate, in bytes.

  `logical_space: VolumeConstituentsSpaceLogicalSpace GET POST PATCH`

    The logical_space field of the volume_constituents_space.

  `max_size: str GET POST PATCH`

    Indicates the maximum size supported for each constituent of the FlexGroup volume.

    Valid choices:

    - 100T
    - 300T
    - 600T
  `metadata: Size GET`

    Space used by the volume metadata in the aggregate, in bytes.

  `over_provisioned: Size GET`

    The amount of space not available for this volume in the aggregate, in bytes.

  `performance_tier_footprint: Size GET`

    Space used by the performance tier for this volume in the FabricPool aggregate, in bytes.

  `size: Size GET POST PATCH`

    Total provisioned size. The default size is equal to the minimum size of 20MB, in bytes.

  `snapshot: VolumeConstituentsSpaceSnapshot GET POST PATCH`

    The snapshot field of the volume_constituents_space.

  `total_footprint: Size GET`

    Data and metadata used for this volume in the aggregate, in bytes.

  `total_metadata: Size GET`

    Space used by the total metadata in the volume, in bytes.

  `total_metadata_footprint: Size GET`

    Space used by the volume metadata footprint in the aggregate, in bytes.

  `used: Size GET`

    The virtual space used (includes volume reserves) before storage efficiency, in bytes.

  `used_by_afs: Size GET POST PATCH`

    The space used by Active Filesystem, in bytes.

  `used_percent: Size GET POST PATCH`

    The virtual space used (includes volume reserves) before storage efficiency, as a percent.